@@ -1,7 +1,7 @@
 enum {
 	THREAD_NONE, THREAD_ADD, THREAD_DELETE, THREAD_EXTRACT,
 	THREAD_VIEW, THREAD_DRAGOUT, THREAD_DRAGTOEXPLORER,
-	THREAD_DRAGTOWIN2KEXPLORER, THREAD_MAKEEXE, THREAD_TEST
+	THREAD_DRAGTOWIN2KEXPLORER, THREAD_TEST
 };
 
 extern char ThreadType;
@@ -9,7 +9,6 @@ extern HANDLE hThread;
 
 void AddThread(void);
 void ExtractThread(void);
-void MakeExeThread(void);
 void MsgLoop(void);
 void RunThread(void (*)(void), int);
 void ThreadCleanUp(void);
